summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/nile.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/nile.cpp')
-rw-r--r--src/devices/sound/nile.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/devices/sound/nile.cpp b/src/devices/sound/nile.cpp
index 80023870593..aeaeeaca59c 100644
--- a/src/devices/sound/nile.cpp
+++ b/src/devices/sound/nile.cpp
@@ -68,7 +68,7 @@ nile_device::nile_device(const machine_config &mconfig, const char *tag, device_
void nile_device::device_start()
{
- m_stream = stream_alloc(0, 2, 44100);
+ m_stream = stream_alloc_legacy(0, 2, 44100);
save_item(NAME(m_sound_regs));
save_item(NAME(m_vpos));
save_item(NAME(m_frac));
@@ -78,11 +78,11 @@ void nile_device::device_start()
//-------------------------------------------------
// sound_stream_update - handle update requests
// for our sound stream
//-------------------------------------------------
-void nile_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void nile_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
uint8_t *sound_ram = &m_sound_ram[0];
int v, i, snum;
@@ -78,11 +78,11 @@ void nile_device::device_start()
//-------------------------------------------------
-// sound_stream_update - handle update requests
+// sound_stream_update_legacy - handle update requests
// for our sound stream
//-------------------------------------------------